"use strict";
var BuiltinSearch = (function () {
    function BuiltinSearch(listener) {
        this.listener = listener;
        this.listener.on('found-in-page', this.matchFound.bind(this));
        this.listener.on('ipc-message', this.onIpcMessage.bind(this));
    }
    BuiltinSearch.prototype.startFinding = function (text) {
        console.log('start!: ', text);
        this.requestId = this.listener.findInPage(text);
    };
    BuiltinSearch.prototype.stopFinding = function () {
        console.log('stop!: ', this.requestId);
        this.listener.stopFindInPage('clearSelection');
    };
    BuiltinSearch.prototype.findNext = function (text, forward) {
        console.log('next!:', text);
        this.requestId = this.listener.findInPage(text, {
            forward: forward,
            findNext: true,
        });
    };
    BuiltinSearch.prototype.sendMatchResult = function (active, all) {
        this.listener.send('builtin-search:match-result', active, all);
    };
    BuiltinSearch.prototype.onIpcMessage = function (event, args) {
        console.log('builtin-search:onIpcMessage: ', args);
        var channel = args[0];
        switch (channel) {
            case 'builtin-search:start-finding': {
                this.startFinding(args[1]);
                break;
            }
            case 'builtin-search:stop-finding': {
                this.stopFinding();
                break;
            }
            case 'builtin-search:find-next': {
                this.findNext(args[1], args[2]);
                break;
            }
            default:
                break;
        }
    };
    BuiltinSearch.prototype.matchFound = function (event, result) {
        console.log(result, result.activeMatchOrdinal, result.matches, result.selectionArea);
        if (this.requestId !== result.requestId) {
            return;
        }
        if (result.activeMatchOrdinal) {
            this.activeMatchIdx = result.activeMatchOrdinal;
        }
        if (result.finalUpdate && result.matches !== undefined) {
            this.sendMatchResult(this.activeMatchIdx, result.matches);
        }
    };
    return BuiltinSearch;
}());
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = BuiltinSearch;
//# sourceMappingURL=builtin-search.js.map