"use strict";
var marked = require('marked');
var katex = require('katex');
var highlight_js_1 = require('highlight.js');
var CustomMarkdownRenderer;
(function (CustomMarkdownRenderer) {
    'use strict';
    marked.setOptions({
        highlight: function (code, lang) {
            if (lang === undefined) {
                return code;
            }
            if (lang === 'mermaid') {
                return '<div class="mermaid">' + code + '</div>';
            }
            if (lang === 'katex') {
                return '<div class="katex">' + katex.renderToString(code, { displayMode: true }) + '</div>';
            }
            try {
                return highlight_js_1.highlight(lang, code).value;
            }
            catch (e) {
                console.log('Error on highlight: ' + e.message);
                return code;
            }
        },
    });
    var REGEX_CHECKED_LISTITEM = /^\[x]\s+/;
    var REGEX_UNCHECKED_LISTITEM = /^\[ ]\s+/;
    var renderer = new marked.Renderer();
    renderer.listitem = function (text) {
        var matched = text.match(REGEX_CHECKED_LISTITEM);
        if (matched && matched[0]) {
            return '<li class="task-list-item"><input type="checkbox" class="task-list-item-checkbox" checked="checked" disabled="disabled">'
                + text.slice(matched[0].length) + '</li>\n';
        }
        matched = text.match(REGEX_UNCHECKED_LISTITEM);
        if (matched && matched[0]) {
            return '<li class="task-list-item"><input type="checkbox" class="task-list-item-checkbox" disabled="disabled">'
                + text.slice(matched[0].length) + '</li>\n';
        }
        return marked.Renderer.prototype.listitem.call(this, text);
    };
    function markdown2html(markdown) {
        return marked(markdown, { renderer: renderer });
    }
    exports.default = markdown2html;
})(CustomMarkdownRenderer || (CustomMarkdownRenderer = {}));
//# sourceMappingURL=custom-markdown-renderer.js.map