"use strict";
var initial_path = require('../../browser/initial_path');
var path = require('path');
var assert = require('power-assert');
describe('#initial_path()', function () {
    var argv = process.argv;
    var cwd = process.cwd();
    afterEach(function () {
        process.argv = argv;
        process.chdir(cwd);
    });
    it('returns cwd when no argument is specified in general platform', function () {
        process.argv = [];
        assert(initial_path() === process.cwd());
    });
    it('returns document directory if started with Shiba.app in darwin', function () {
        if (process.platform === 'darwin') {
            process.argv = [];
            process.chdir('/');
            assert(/Documents$/.test(initial_path()));
        }
    });
    it('returns the specified path if it exists', function () {
        process.argv = ['dummy', './README.md'];
        assert(initial_path() === path.resolve('./README.md'));
    });
    it('returns default path if specified path does not exist', function () {
        process.argv = ['dummy', '/this/file/does/not/exist'];
        assert(initial_path() === process.cwd());
    });
    it('returns the last argument of argv if multiple argument specified', function () {
        process.argv = ['dummy', 'foo', 'bar', './README.md'];
        assert(initial_path() === path.resolve('./README.md'));
    });
});
//# sourceMappingURL=initial_path_test.js.map